# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: szconfigmanager.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'szconfigmanager.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15szconfigmanager.proto\x12\x0fszconfigmanager\"%\n\x10GetConfigRequest\x12\x11\n\tconfig_id\x18\x01 \x01(\x03\"#\n\x11GetConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x1a\n\x18GetConfigRegistryRequest\"+\n\x19GetConfigRegistryResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x1b\n\x19GetDefaultConfigIdRequest\",\n\x1aGetDefaultConfigIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"\x1a\n\x18GetTemplateConfigRequest\"+\n\x19GetTemplateConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"J\n\x15RegisterConfigRequest\x12\x19\n\x11\x63onfig_definition\x18\x01 \x01(\t\x12\x16\n\x0e\x63onfig_comment\x18\x02 \x01(\t\"(\n\x16RegisterConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"a\n\x1dReplaceDefaultConfigIdRequest\x12!\n\x19\x63urrent_default_config_id\x18\x01 \x01(\x03\x12\x1d\n\x15new_default_config_id\x18\x02 \x01(\x03\" \n\x1eReplaceDefaultConfigIdResponse\"L\n\x17SetDefaultConfigRequest\x12\x19\n\x11\x63onfig_definition\x18\x01 \x01(\t\x12\x16\n\x0e\x63onfig_comment\x18\x02 \x01(\t\"*\n\x18SetDefaultConfigResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\".\n\x19SetDefaultConfigIdRequest\x12\x11\n\tconfig_id\x18\x01 \x01(\x03\"\x1c\n\x1aSetDefaultConfigIdResponse2\xf2\x06\n\x0fSzConfigManager\x12T\n\tGetConfig\x12!.szconfigmanager.GetConfigRequest\x1a\".szconfigmanager.GetConfigResponse\"\x00\x12l\n\x11GetConfigRegistry\x12).szconfigmanager.GetConfigRegistryRequest\x1a*.szconfigmanager.GetConfigRegistryResponse\"\x00\x12o\n\x12GetDefaultConfigId\x12*.szconfigmanager.GetDefaultConfigIdRequest\x1a+.szconfigmanager.GetDefaultConfigIdResponse\"\x00\x12l\n\x11GetTemplateConfig\x12).szconfigmanager.GetTemplateConfigRequest\x1a*.szconfigmanager.GetTemplateConfigResponse\"\x00\x12\x63\n\x0eRegisterConfig\x12&.szconfigmanager.RegisterConfigRequest\x1a\'.szconfigmanager.RegisterConfigResponse\"\x00\x12{\n\x16ReplaceDefaultConfigId\x12..szconfigmanager.ReplaceDefaultConfigIdRequest\x1a/.szconfigmanager.ReplaceDefaultConfigIdResponse\"\x00\x12i\n\x10SetDefaultConfig\x12(.szconfigmanager.SetDefaultConfigRequest\x1a).szconfigmanager.SetDefaultConfigResponse\"\x00\x12o\n\x12SetDefaultConfigId\x12*.szconfigmanager.SetDefaultConfigIdRequest\x1a+.szconfigmanager.SetDefaultConfigIdResponse\"\x00\x42\x66\n\x14\x63om.senzing.sdk.grpcB\x14SzConfigManagerProtoZ8github.com/senzing-garage/sz-sdk-go-grpc/szconfigmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szconfigmanager_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.senzing.sdk.grpcB\024SzConfigManagerProtoZ8github.com/senzing-garage/sz-sdk-go-grpc/szconfigmanager'
  _globals['_GETCONFIGREQUEST']._serialized_start=42
  _globals['_GETCONFIGREQUEST']._serialized_end=79
  _globals['_GETCONFIGRESPONSE']._serialized_start=81
  _globals['_GETCONFIGRESPONSE']._serialized_end=116
  _globals['_GETCONFIGREGISTRYREQUEST']._serialized_start=118
  _globals['_GETCONFIGREGISTRYREQUEST']._serialized_end=144
  _globals['_GETCONFIGREGISTRYRESPONSE']._serialized_start=146
  _globals['_GETCONFIGREGISTRYRESPONSE']._serialized_end=189
  _globals['_GETDEFAULTCONFIGIDREQUEST']._serialized_start=191
  _globals['_GETDEFAULTCONFIGIDREQUEST']._serialized_end=218
  _globals['_GETDEFAULTCONFIGIDRESPONSE']._serialized_start=220
  _globals['_GETDEFAULTCONFIGIDRESPONSE']._serialized_end=264
  _globals['_GETTEMPLATECONFIGREQUEST']._serialized_start=266
  _globals['_GETTEMPLATECONFIGREQUEST']._serialized_end=292
  _globals['_GETTEMPLATECONFIGRESPONSE']._serialized_start=294
  _globals['_GETTEMPLATECONFIGRESPONSE']._serialized_end=337
  _globals['_REGISTERCONFIGREQUEST']._serialized_start=339
  _globals['_REGISTERCONFIGREQUEST']._serialized_end=413
  _globals['_REGISTERCONFIGRESPONSE']._serialized_start=415
  _globals['_REGISTERCONFIGRESPONSE']._serialized_end=455
  _globals['_REPLACEDEFAULTCONFIGIDREQUEST']._serialized_start=457
  _globals['_REPLACEDEFAULTCONFIGIDREQUEST']._serialized_end=554
  _globals['_REPLACEDEFAULTCONFIGIDRESPONSE']._serialized_start=556
  _globals['_REPLACEDEFAULTCONFIGIDRESPONSE']._serialized_end=588
  _globals['_SETDEFAULTCONFIGREQUEST']._serialized_start=590
  _globals['_SETDEFAULTCONFIGREQUEST']._serialized_end=666
  _globals['_SETDEFAULTCONFIGRESPONSE']._serialized_start=668
  _globals['_SETDEFAULTCONFIGRESPONSE']._serialized_end=710
  _globals['_SETDEFAULTCONFIGIDREQUEST']._serialized_start=712
  _globals['_SETDEFAULTCONFIGIDREQUEST']._serialized_end=758
  _globals['_SETDEFAULTCONFIGIDRESPONSE']._serialized_start=760
  _globals['_SETDEFAULTCONFIGIDRESPONSE']._serialized_end=788
  _globals['_SZCONFIGMANAGER']._serialized_start=791
  _globals['_SZCONFIGMANAGER']._serialized_end=1673
# @@protoc_insertion_point(module_scope)
