# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: szproduct.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'szproduct.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fszproduct.proto\x12\tszproduct\"\x13\n\x11GetLicenseRequest\"$\n\x12GetLicenseResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x13\n\x11GetVersionRequest\"$\n\x12GetVersionResponse\x12\x0e\n\x06result\x18\x01 \x01(\t2\xa5\x01\n\tSzProduct\x12K\n\nGetLicense\x12\x1c.szproduct.GetLicenseRequest\x1a\x1d.szproduct.GetLicenseResponse\"\x00\x12K\n\nGetVersion\x12\x1c.szproduct.GetVersionRequest\x1a\x1d.szproduct.GetVersionResponse\"\x00\x42Z\n\x14\x63om.senzing.sdk.grpcB\x0eSzProductProtoZ2github.com/senzing-garage/sz-sdk-go-grpc/szproductb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szproduct_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.senzing.sdk.grpcB\016SzProductProtoZ2github.com/senzing-garage/sz-sdk-go-grpc/szproduct'
  _globals['_GETLICENSEREQUEST']._serialized_start=30
  _globals['_GETLICENSEREQUEST']._serialized_end=49
  _globals['_GETLICENSERESPONSE']._serialized_start=51
  _globals['_GETLICENSERESPONSE']._serialized_end=87
  _globals['_GETVERSIONREQUEST']._serialized_start=89
  _globals['_GETVERSIONREQUEST']._serialized_end=108
  _globals['_GETVERSIONRESPONSE']._serialized_start=110
  _globals['_GETVERSIONRESPONSE']._serialized_end=146
  _globals['_SZPRODUCT']._serialized_start=149
  _globals['_SZPRODUCT']._serialized_end=314
# @@protoc_insertion_point(module_scope)
