# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: szengine.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'szengine.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eszengine.proto\x12\x08szengine\"i\n\x10\x41\x64\x64RecordRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\x19\n\x11record_definition\x18\x03 \x01(\t\x12\r\n\x05\x66lags\x18\x04 \x01(\x03\"#\n\x11\x41\x64\x64RecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"+\n\x12\x43loseExportRequest\x12\x15\n\rexport_handle\x18\x01 \x01(\x03\"\x15\n\x13\x43loseExportResponse\"\x19\n\x17\x43ountRedoRecordsRequest\"*\n\x18\x43ountRedoRecordsResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\"Q\n\x13\x44\x65leteRecordRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"&\n\x14\x44\x65leteRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"F\n\x1c\x45xportCsvEntityReportRequest\x12\x17\n\x0f\x63sv_column_list\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"/\n\x1d\x45xportCsvEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\".\n\x1d\x45xportJsonEntityReportRequest\x12\r\n\x05\x66lags\x18\x01 \x01(\x03\"0\n\x1e\x45xportJsonEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\")\n\x10\x46\x65tchNextRequest\x12\x15\n\rexport_handle\x18\x01 \x01(\x03\"#\n\x11\x46\x65tchNextResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"L\n(FindInterestingEntitiesByEntityIdRequest\x12\x11\n\tentity_id\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\";\n)FindInterestingEntitiesByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"f\n(FindInterestingEntitiesByRecordIdRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\";\n)FindInterestingEntitiesByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x91\x01\n\x1c\x46indNetworkByEntityIdRequest\x12\x12\n\nentity_ids\x18\x01 \x01(\t\x12\x13\n\x0bmax_degrees\x18\x02 \x01(\x03\x12\x19\n\x11\x62uild_out_degrees\x18\x03 \x01(\x03\x12\x1e\n\x16\x62uild_out_max_entities\x18\x04 \x01(\x03\x12\r\n\x05\x66lags\x18\x05 \x01(\x03\"/\n\x1d\x46indNetworkByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x92\x01\n\x1c\x46indNetworkByRecordIdRequest\x12\x13\n\x0brecord_keys\x18\x01 \x01(\t\x12\x13\n\x0bmax_degrees\x18\x02 \x01(\x03\x12\x19\n\x11\x62uild_out_degrees\x18\x03 \x01(\x03\x12\x1e\n\x16\x62uild_out_max_entities\x18\x04 \x01(\x03\x12\r\n\x05\x66lags\x18\x05 \x01(\x03\"/\n\x1d\x46indNetworkByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\xa8\x01\n\x19\x46indPathByEntityIdRequest\x12\x17\n\x0fstart_entity_id\x18\x01 \x01(\x03\x12\x15\n\rend_entity_id\x18\x02 \x01(\x03\x12\x13\n\x0bmax_degrees\x18\x03 \x01(\x03\x12\x18\n\x10\x61void_entity_ids\x18\x04 \x01(\t\x12\x1d\n\x15required_data_sources\x18\x05 \x01(\t\x12\r\n\x05\x66lags\x18\x06 \x01(\x03\",\n\x1a\x46indPathByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\xe7\x01\n\x19\x46indPathByRecordIdRequest\x12\x1e\n\x16start_data_source_code\x18\x01 \x01(\t\x12\x17\n\x0fstart_record_id\x18\x02 \x01(\t\x12\x1c\n\x14\x65nd_data_source_code\x18\x03 \x01(\t\x12\x15\n\rend_record_id\x18\x04 \x01(\t\x12\x13\n\x0bmax_degrees\x18\x05 \x01(\x03\x12\x19\n\x11\x61void_record_keys\x18\x06 \x01(\t\x12\x1d\n\x15required_data_sources\x18\x07 \x01(\t\x12\r\n\x05\x66lags\x18\x08 \x01(\x03\",\n\x1a\x46indPathByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x1a\n\x18GetActiveConfigIdRequest\"+\n\x19GetActiveConfigIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\x03\">\n\x1aGetEntityByEntityIdRequest\x12\x11\n\tentity_id\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"-\n\x1bGetEntityByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"X\n\x1aGetEntityByRecordIdRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"-\n\x1bGetEntityByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"N\n\x10GetRecordRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"#\n\x11GetRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x16\n\x14GetRedoRecordRequest\"\'\n\x15GetRedoRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x11\n\x0fGetStatsRequest\"\"\n\x10GetStatsResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"G\n!GetVirtualEntityByRecordIdRequest\x12\x13\n\x0brecord_keys\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"4\n\"GetVirtualEntityByRecordIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\">\n\x1aHowEntityByEntityIdRequest\x12\x11\n\tentity_id\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"-\n\x1bHowEntityByEntityIdResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"C\n\x17PreprocessRecordRequest\x12\x19\n\x11record_definition\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"*\n\x18PreprocessRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x14\n\x12PrimeEngineRequest\"\x15\n\x13PrimeEngineResponse\">\n\x18ProcessRedoRecordRequest\x12\x13\n\x0bredo_record\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"+\n\x19ProcessRedoRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\";\n\x17ReevaluateEntityRequest\x12\x11\n\tentity_id\x18\x01 \x01(\x03\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"*\n\x18ReevaluateEntityResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"U\n\x17ReevaluateRecordRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"*\n\x18ReevaluateRecordResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"(\n\x13ReinitializeRequest\x12\x11\n\tconfig_id\x18\x01 \x01(\x03\"\x16\n\x14ReinitializeResponse\"V\n\x19SearchByAttributesRequest\x12\x12\n\nattributes\x18\x01 \x01(\t\x12\x16\n\x0esearch_profile\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\",\n\x1aSearchByAttributesResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"L\n\"StreamExportCsvEntityReportRequest\x12\x17\n\x0f\x63sv_column_list\x18\x01 \x01(\t\x12\r\n\x05\x66lags\x18\x02 \x01(\x03\"5\n#StreamExportCsvEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"4\n#StreamExportJsonEntityReportRequest\x12\r\n\x05\x66lags\x18\x01 \x01(\x03\"6\n$StreamExportJsonEntityReportResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"M\n\x12WhyEntitiesRequest\x12\x13\n\x0b\x65ntity_id_1\x18\x01 \x01(\x03\x12\x13\n\x0b\x65ntity_id_2\x18\x02 \x01(\x03\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"%\n\x13WhyEntitiesResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"V\n\x18WhyRecordInEntityRequest\x12\x18\n\x10\x64\x61ta_source_code\x18\x01 \x01(\t\x12\x11\n\trecord_id\x18\x02 \x01(\t\x12\r\n\x05\x66lags\x18\x03 \x01(\x03\"+\n\x19WhyRecordInEntityResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x84\x01\n\x11WhyRecordsRequest\x12\x1a\n\x12\x64\x61ta_source_code_1\x18\x01 \x01(\t\x12\x13\n\x0brecord_id_1\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x61ta_source_code_2\x18\x03 \x01(\t\x12\x13\n\x0brecord_id_2\x18\x04 \x01(\t\x12\r\n\x05\x66lags\x18\x05 \x01(\x03\"$\n\x12WhyRecordsResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"`\n\x10WhySearchRequest\x12\x12\n\nattributes\x18\x01 \x01(\t\x12\x11\n\tentity_id\x18\x02 \x01(\x03\x12\x16\n\x0esearch_profile\x18\x03 \x01(\t\x12\r\n\x05\x66lags\x18\x04 \x01(\x03\"#\n\x11WhySearchResponse\x12\x0e\n\x06result\x18\x01 \x01(\t2\xdd\x19\n\x08SzEngine\x12\x46\n\tAddRecord\x12\x1a.szengine.AddRecordRequest\x1a\x1b.szengine.AddRecordResponse\"\x00\x12L\n\x0b\x43loseExport\x12\x1c.szengine.CloseExportRequest\x1a\x1d.szengine.CloseExportResponse\"\x00\x12[\n\x10\x43ountRedoRecords\x12!.szengine.CountRedoRecordsRequest\x1a\".szengine.CountRedoRecordsResponse\"\x00\x12O\n\x0c\x44\x65leteRecord\x12\x1d.szengine.DeleteRecordRequest\x1a\x1e.szengine.DeleteRecordResponse\"\x00\x12j\n\x15\x45xportCsvEntityReport\x12&.szengine.ExportCsvEntityReportRequest\x1a\'.szengine.ExportCsvEntityReportResponse\"\x00\x12m\n\x16\x45xportJsonEntityReport\x12\'.szengine.ExportJsonEntityReportRequest\x1a(.szengine.ExportJsonEntityReportResponse\"\x00\x12\x46\n\tFetchNext\x12\x1a.szengine.FetchNextRequest\x1a\x1b.szengine.FetchNextResponse\"\x00\x12\x8e\x01\n!FindInterestingEntitiesByEntityId\x12\x32.szengine.FindInterestingEntitiesByEntityIdRequest\x1a\x33.szengine.FindInterestingEntitiesByEntityIdResponse\"\x00\x12\x8e\x01\n!FindInterestingEntitiesByRecordId\x12\x32.szengine.FindInterestingEntitiesByRecordIdRequest\x1a\x33.szengine.FindInterestingEntitiesByRecordIdResponse\"\x00\x12j\n\x15\x46indNetworkByEntityId\x12&.szengine.FindNetworkByEntityIdRequest\x1a\'.szengine.FindNetworkByEntityIdResponse\"\x00\x12j\n\x15\x46indNetworkByRecordId\x12&.szengine.FindNetworkByRecordIdRequest\x1a\'.szengine.FindNetworkByRecordIdResponse\"\x00\x12\x61\n\x12\x46indPathByEntityId\x12#.szengine.FindPathByEntityIdRequest\x1a$.szengine.FindPathByEntityIdResponse\"\x00\x12\x61\n\x12\x46indPathByRecordId\x12#.szengine.FindPathByRecordIdRequest\x1a$.szengine.FindPathByRecordIdResponse\"\x00\x12^\n\x11GetActiveConfigId\x12\".szengine.GetActiveConfigIdRequest\x1a#.szengine.GetActiveConfigIdResponse\"\x00\x12\x64\n\x13GetEntityByEntityId\x12$.szengine.GetEntityByEntityIdRequest\x1a%.szengine.GetEntityByEntityIdResponse\"\x00\x12\x64\n\x13GetEntityByRecordId\x12$.szengine.GetEntityByRecordIdRequest\x1a%.szengine.GetEntityByRecordIdResponse\"\x00\x12\x46\n\tGetRecord\x12\x1a.szengine.GetRecordRequest\x1a\x1b.szengine.GetRecordResponse\"\x00\x12R\n\rGetRedoRecord\x12\x1e.szengine.GetRedoRecordRequest\x1a\x1f.szengine.GetRedoRecordResponse\"\x00\x12\x43\n\x08GetStats\x12\x19.szengine.GetStatsRequest\x1a\x1a.szengine.GetStatsResponse\"\x00\x12y\n\x1aGetVirtualEntityByRecordId\x12+.szengine.GetVirtualEntityByRecordIdRequest\x1a,.szengine.GetVirtualEntityByRecordIdResponse\"\x00\x12\x64\n\x13HowEntityByEntityId\x12$.szengine.HowEntityByEntityIdRequest\x1a%.szengine.HowEntityByEntityIdResponse\"\x00\x12[\n\x10PreprocessRecord\x12!.szengine.PreprocessRecordRequest\x1a\".szengine.PreprocessRecordResponse\"\x00\x12L\n\x0bPrimeEngine\x12\x1c.szengine.PrimeEngineRequest\x1a\x1d.szengine.PrimeEngineResponse\"\x00\x12^\n\x11ProcessRedoRecord\x12\".szengine.ProcessRedoRecordRequest\x1a#.szengine.ProcessRedoRecordResponse\"\x00\x12[\n\x10ReevaluateEntity\x12!.szengine.ReevaluateEntityRequest\x1a\".szengine.ReevaluateEntityResponse\"\x00\x12[\n\x10ReevaluateRecord\x12!.szengine.ReevaluateRecordRequest\x1a\".szengine.ReevaluateRecordResponse\"\x00\x12O\n\x0cReinitialize\x12\x1d.szengine.ReinitializeRequest\x1a\x1e.szengine.ReinitializeResponse\"\x00\x12\x61\n\x12SearchByAttributes\x12#.szengine.SearchByAttributesRequest\x1a$.szengine.SearchByAttributesResponse\"\x00\x12~\n\x1bStreamExportCsvEntityReport\x12,.szengine.StreamExportCsvEntityReportRequest\x1a-.szengine.StreamExportCsvEntityReportResponse\"\x00\x30\x01\x12\x81\x01\n\x1cStreamExportJsonEntityReport\x12-.szengine.StreamExportJsonEntityReportRequest\x1a..szengine.StreamExportJsonEntityReportResponse\"\x00\x30\x01\x12L\n\x0bWhyEntities\x12\x1c.szengine.WhyEntitiesRequest\x1a\x1d.szengine.WhyEntitiesResponse\"\x00\x12^\n\x11WhyRecordInEntity\x12\".szengine.WhyRecordInEntityRequest\x1a#.szengine.WhyRecordInEntityResponse\"\x00\x12I\n\nWhyRecords\x12\x1b.szengine.WhyRecordsRequest\x1a\x1c.szengine.WhyRecordsResponse\"\x00\x12\x46\n\tWhySearch\x12\x1a.szengine.WhySearchRequest\x1a\x1b.szengine.WhySearchResponse\"\x00\x42X\n\x14\x63om.senzing.sdk.grpcB\rSzEngineProtoZ1github.com/senzing-garage/sz-sdk-go-grpc/szengineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'szengine_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.senzing.sdk.grpcB\rSzEngineProtoZ1github.com/senzing-garage/sz-sdk-go-grpc/szengine'
  _globals['_ADDRECORDREQUEST']._serialized_start=28
  _globals['_ADDRECORDREQUEST']._serialized_end=133
  _globals['_ADDRECORDRESPONSE']._serialized_start=135
  _globals['_ADDRECORDRESPONSE']._serialized_end=170
  _globals['_CLOSEEXPORTREQUEST']._serialized_start=172
  _globals['_CLOSEEXPORTREQUEST']._serialized_end=215
  _globals['_CLOSEEXPORTRESPONSE']._serialized_start=217
  _globals['_CLOSEEXPORTRESPONSE']._serialized_end=238
  _globals['_COUNTREDORECORDSREQUEST']._serialized_start=240
  _globals['_COUNTREDORECORDSREQUEST']._serialized_end=265
  _globals['_COUNTREDORECORDSRESPONSE']._serialized_start=267
  _globals['_COUNTREDORECORDSRESPONSE']._serialized_end=309
  _globals['_DELETERECORDREQUEST']._serialized_start=311
  _globals['_DELETERECORDREQUEST']._serialized_end=392
  _globals['_DELETERECORDRESPONSE']._serialized_start=394
  _globals['_DELETERECORDRESPONSE']._serialized_end=432
  _globals['_EXPORTCSVENTITYREPORTREQUEST']._serialized_start=434
  _globals['_EXPORTCSVENTITYREPORTREQUEST']._serialized_end=504
  _globals['_EXPORTCSVENTITYREPORTRESPONSE']._serialized_start=506
  _globals['_EXPORTCSVENTITYREPORTRESPONSE']._serialized_end=553
  _globals['_EXPORTJSONENTITYREPORTREQUEST']._serialized_start=555
  _globals['_EXPORTJSONENTITYREPORTREQUEST']._serialized_end=601
  _globals['_EXPORTJSONENTITYREPORTRESPONSE']._serialized_start=603
  _globals['_EXPORTJSONENTITYREPORTRESPONSE']._serialized_end=651
  _globals['_FETCHNEXTREQUEST']._serialized_start=653
  _globals['_FETCHNEXTREQUEST']._serialized_end=694
  _globals['_FETCHNEXTRESPONSE']._serialized_start=696
  _globals['_FETCHNEXTRESPONSE']._serialized_end=731
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDREQUEST']._serialized_start=733
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDREQUEST']._serialized_end=809
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDRESPONSE']._serialized_start=811
  _globals['_FINDINTERESTINGENTITIESBYENTITYIDRESPONSE']._serialized_end=870
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDREQUEST']._serialized_start=872
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDREQUEST']._serialized_end=974
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDRESPONSE']._serialized_start=976
  _globals['_FINDINTERESTINGENTITIESBYRECORDIDRESPONSE']._serialized_end=1035
  _globals['_FINDNETWORKBYENTITYIDREQUEST']._serialized_start=1038
  _globals['_FINDNETWORKBYENTITYIDREQUEST']._serialized_end=1183
  _globals['_FINDNETWORKBYENTITYIDRESPONSE']._serialized_start=1185
  _globals['_FINDNETWORKBYENTITYIDRESPONSE']._serialized_end=1232
  _globals['_FINDNETWORKBYRECORDIDREQUEST']._serialized_start=1235
  _globals['_FINDNETWORKBYRECORDIDREQUEST']._serialized_end=1381
  _globals['_FINDNETWORKBYRECORDIDRESPONSE']._serialized_start=1383
  _globals['_FINDNETWORKBYRECORDIDRESPONSE']._serialized_end=1430
  _globals['_FINDPATHBYENTITYIDREQUEST']._serialized_start=1433
  _globals['_FINDPATHBYENTITYIDREQUEST']._serialized_end=1601
  _globals['_FINDPATHBYENTITYIDRESPONSE']._serialized_start=1603
  _globals['_FINDPATHBYENTITYIDRESPONSE']._serialized_end=1647
  _globals['_FINDPATHBYRECORDIDREQUEST']._serialized_start=1650
  _globals['_FINDPATHBYRECORDIDREQUEST']._serialized_end=1881
  _globals['_FINDPATHBYRECORDIDRESPONSE']._serialized_start=1883
  _globals['_FINDPATHBYRECORDIDRESPONSE']._serialized_end=1927
  _globals['_GETACTIVECONFIGIDREQUEST']._serialized_start=1929
  _globals['_GETACTIVECONFIGIDREQUEST']._serialized_end=1955
  _globals['_GETACTIVECONFIGIDRESPONSE']._serialized_start=1957
  _globals['_GETACTIVECONFIGIDRESPONSE']._serialized_end=2000
  _globals['_GETENTITYBYENTITYIDREQUEST']._serialized_start=2002
  _globals['_GETENTITYBYENTITYIDREQUEST']._serialized_end=2064
  _globals['_GETENTITYBYENTITYIDRESPONSE']._serialized_start=2066
  _globals['_GETENTITYBYENTITYIDRESPONSE']._serialized_end=2111
  _globals['_GETENTITYBYRECORDIDREQUEST']._serialized_start=2113
  _globals['_GETENTITYBYRECORDIDREQUEST']._serialized_end=2201
  _globals['_GETENTITYBYRECORDIDRESPONSE']._serialized_start=2203
  _globals['_GETENTITYBYRECORDIDRESPONSE']._serialized_end=2248
  _globals['_GETRECORDREQUEST']._serialized_start=2250
  _globals['_GETRECORDREQUEST']._serialized_end=2328
  _globals['_GETRECORDRESPONSE']._serialized_start=2330
  _globals['_GETRECORDRESPONSE']._serialized_end=2365
  _globals['_GETREDORECORDREQUEST']._serialized_start=2367
  _globals['_GETREDORECORDREQUEST']._serialized_end=2389
  _globals['_GETREDORECORDRESPONSE']._serialized_start=2391
  _globals['_GETREDORECORDRESPONSE']._serialized_end=2430
  _globals['_GETSTATSREQUEST']._serialized_start=2432
  _globals['_GETSTATSREQUEST']._serialized_end=2449
  _globals['_GETSTATSRESPONSE']._serialized_start=2451
  _globals['_GETSTATSRESPONSE']._serialized_end=2485
  _globals['_GETVIRTUALENTITYBYRECORDIDREQUEST']._serialized_start=2487
  _globals['_GETVIRTUALENTITYBYRECORDIDREQUEST']._serialized_end=2558
  _globals['_GETVIRTUALENTITYBYRECORDIDRESPONSE']._serialized_start=2560
  _globals['_GETVIRTUALENTITYBYRECORDIDRESPONSE']._serialized_end=2612
  _globals['_HOWENTITYBYENTITYIDREQUEST']._serialized_start=2614
  _globals['_HOWENTITYBYENTITYIDREQUEST']._serialized_end=2676
  _globals['_HOWENTITYBYENTITYIDRESPONSE']._serialized_start=2678
  _globals['_HOWENTITYBYENTITYIDRESPONSE']._serialized_end=2723
  _globals['_PREPROCESSRECORDREQUEST']._serialized_start=2725
  _globals['_PREPROCESSRECORDREQUEST']._serialized_end=2792
  _globals['_PREPROCESSRECORDRESPONSE']._serialized_start=2794
  _globals['_PREPROCESSRECORDRESPONSE']._serialized_end=2836
  _globals['_PRIMEENGINEREQUEST']._serialized_start=2838
  _globals['_PRIMEENGINEREQUEST']._serialized_end=2858
  _globals['_PRIMEENGINERESPONSE']._serialized_start=2860
  _globals['_PRIMEENGINERESPONSE']._serialized_end=2881
  _globals['_PROCESSREDORECORDREQUEST']._serialized_start=2883
  _globals['_PROCESSREDORECORDREQUEST']._serialized_end=2945
  _globals['_PROCESSREDORECORDRESPONSE']._serialized_start=2947
  _globals['_PROCESSREDORECORDRESPONSE']._serialized_end=2990
  _globals['_REEVALUATEENTITYREQUEST']._serialized_start=2992
  _globals['_REEVALUATEENTITYREQUEST']._serialized_end=3051
  _globals['_REEVALUATEENTITYRESPONSE']._serialized_start=3053
  _globals['_REEVALUATEENTITYRESPONSE']._serialized_end=3095
  _globals['_REEVALUATERECORDREQUEST']._serialized_start=3097
  _globals['_REEVALUATERECORDREQUEST']._serialized_end=3182
  _globals['_REEVALUATERECORDRESPONSE']._serialized_start=3184
  _globals['_REEVALUATERECORDRESPONSE']._serialized_end=3226
  _globals['_REINITIALIZEREQUEST']._serialized_start=3228
  _globals['_REINITIALIZEREQUEST']._serialized_end=3268
  _globals['_REINITIALIZERESPONSE']._serialized_start=3270
  _globals['_REINITIALIZERESPONSE']._serialized_end=3292
  _globals['_SEARCHBYATTRIBUTESREQUEST']._serialized_start=3294
  _globals['_SEARCHBYATTRIBUTESREQUEST']._serialized_end=3380
  _globals['_SEARCHBYATTRIBUTESRESPONSE']._serialized_start=3382
  _globals['_SEARCHBYATTRIBUTESRESPONSE']._serialized_end=3426
  _globals['_STREAMEXPORTCSVENTITYREPORTREQUEST']._serialized_start=3428
  _globals['_STREAMEXPORTCSVENTITYREPORTREQUEST']._serialized_end=3504
  _globals['_STREAMEXPORTCSVENTITYREPORTRESPONSE']._serialized_start=3506
  _globals['_STREAMEXPORTCSVENTITYREPORTRESPONSE']._serialized_end=3559
  _globals['_STREAMEXPORTJSONENTITYREPORTREQUEST']._serialized_start=3561
  _globals['_STREAMEXPORTJSONENTITYREPORTREQUEST']._serialized_end=3613
  _globals['_STREAMEXPORTJSONENTITYREPORTRESPONSE']._serialized_start=3615
  _globals['_STREAMEXPORTJSONENTITYREPORTRESPONSE']._serialized_end=3669
  _globals['_WHYENTITIESREQUEST']._serialized_start=3671
  _globals['_WHYENTITIESREQUEST']._serialized_end=3748
  _globals['_WHYENTITIESRESPONSE']._serialized_start=3750
  _globals['_WHYENTITIESRESPONSE']._serialized_end=3787
  _globals['_WHYRECORDINENTITYREQUEST']._serialized_start=3789
  _globals['_WHYRECORDINENTITYREQUEST']._serialized_end=3875
  _globals['_WHYRECORDINENTITYRESPONSE']._serialized_start=3877
  _globals['_WHYRECORDINENTITYRESPONSE']._serialized_end=3920
  _globals['_WHYRECORDSREQUEST']._serialized_start=3923
  _globals['_WHYRECORDSREQUEST']._serialized_end=4055
  _globals['_WHYRECORDSRESPONSE']._serialized_start=4057
  _globals['_WHYRECORDSRESPONSE']._serialized_end=4093
  _globals['_WHYSEARCHREQUEST']._serialized_start=4095
  _globals['_WHYSEARCHREQUEST']._serialized_end=4191
  _globals['_WHYSEARCHRESPONSE']._serialized_start=4193
  _globals['_WHYSEARCHRESPONSE']._serialized_end=4228
  _globals['_SZENGINE']._serialized_start=4231
  _globals['_SZENGINE']._serialized_end=7524
# @@protoc_insertion_point(module_scope)
